@@ -1,16 +1,16 @@
 """Certbot display."""
 import logging
-import os
 import sys
 import textwrap
 
 import zope.interface
 
-from certbot import constants
+from certbot._internal import constants
 from certbot import errors
 from certbot import interfaces
 from certbot.compat import misc
-from certbot.display import completer
+from certbot.compat import os
+from certbot._internal.display import completer
 
 logger = logging.getLogger(__name__)
 
@@ -89,7 +89,6 @@ def input_with_timeout(prompt=None, timeout=36000.0):
 @zope.interface.implementer(interfaces.IDisplay)
 class FileDisplay(object):
     """File-based display."""
-    # pylint: disable=too-many-arguments
     # see https://github.com/certbot/certbot/issues/3915
 
     def __init__(self, outfile, force_interactive):
@@ -114,7 +113,7 @@ class FileDisplay(object):
             message = _wrap_lines(message)
         self.outfile.write(
             "{line}{frame}{line}{msg}{line}{frame}{line}".format(
-                line=os.linesep, frame=SIDE_FRAME, msg=message))
+                line='\n', frame=SIDE_FRAME, msg=message))
         self.outfile.flush()
         if pause:
             if self._can_interact(force_interactive):
@@ -122,10 +121,9 @@ class FileDisplay(object):
             else:
                 logger.debug("Not pausing for user confirmation")
 
-    def menu(self, message, choices, ok_label=None, cancel_label=None,
-             help_label=None, default=None,
+    def menu(self, message, choices, ok_label=None, cancel_label=None,  # pylint: disable=unused-argument
+             help_label=None, default=None,  # pylint: disable=unused-argument
              cli_flag=None, force_interactive=False, **unused_kwargs):
-        # pylint: disable=unused-argument
         """Display a menu.
 
         .. todo:: This doesn't enable the help label/button (I wasn't sold on
@@ -181,8 +179,7 @@ class FileDisplay(object):
 
         if ans == "c" or ans == "C":
             return CANCEL, "-1"
-        else:
-            return OK, ans
+        return OK, ans
 
     def yesno(self, message, yes_label="Yes", no_label="No", default=None,
               cli_flag=None, force_interactive=False, **unused_kwargs):
@@ -228,7 +225,6 @@ class FileDisplay(object):
 
     def checklist(self, message, tags, default=None,
                   cli_flag=None, force_interactive=False, **unused_kwargs):
-        # pylint: disable=unused-argument
         """Display a checklist.
 
         :param str message: Message to display to user
@@ -256,7 +252,7 @@ class FileDisplay(object):
                                    force_interactive=True)
 
             if code == OK:
-                if len(ans.strip()) == 0:
+                if not ans.strip():
                     ans = " ".join(str(x) for x in range(1, len(tags)+1))
                 indices = separate_list_input(ans)
                 selected_tags = self._scrub_checklist_input(indices, tags)
@@ -468,8 +464,7 @@ class NoninteractiveDisplay(object):
             msg += "\n\n(You can set this with the {0} flag)".format(cli_flag)
         raise errors.MissingCommandlineFlag(msg)
 
-    def notification(self, message, pause=False, wrap=True, **unused_kwargs):
-        # pylint: disable=unused-argument
+    def notification(self, message, pause=False, wrap=True, **unused_kwargs):  # pylint: disable=unused-argument
         """Displays a notification without waiting for user acceptance.
 
         :param str message: Message to display to stdout
@@ -486,7 +481,7 @@ class NoninteractiveDisplay(object):
 
     def menu(self, message, choices, ok_label=None, cancel_label=None,
              help_label=None, default=None, cli_flag=None, **unused_kwargs):
-        # pylint: disable=unused-argument,too-many-arguments
+        # pylint: disable=unused-argument
         """Avoid displaying a menu.
 
         :param str message: title of menu
@@ -522,12 +517,10 @@ class NoninteractiveDisplay(object):
         """
         if default is None:
             self._interaction_fail(message, cli_flag)
-        else:
-            return OK, default
+        return OK, default
 
-    def yesno(self, message, yes_label=None, no_label=None,
+    def yesno(self, message, yes_label=None, no_label=None,  # pylint: disable=unused-argument
               default=None, cli_flag=None, **unused_kwargs):
-        # pylint: disable=unused-argument
         """Decide Yes or No, without asking anybody
 
         :param str message: question for the user
@@ -540,8 +533,7 @@ class NoninteractiveDisplay(object):
         """
         if default is None:
             self._interaction_fail(message, cli_flag)
-        else:
-            return default
+        return default
 
     def checklist(self, message, tags, default=None,
                   cli_flag=None, **unused_kwargs):
@@ -559,8 +551,7 @@ class NoninteractiveDisplay(object):
         """
         if default is None:
             self._interaction_fail(message, cli_flag, "? ".join(tags))
-        else:
-            return OK, default
+        return OK, default
 
     def directory_select(self, message, default=None,
                          cli_flag=None, **unused_kwargs):
