@@ -4,7 +4,6 @@ import six
 import zope.interface
 
 # pylint: disable=no-self-argument,no-method-argument,no-init,inherit-non-class
-# pylint: disable=too-few-public-methods
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -73,7 +72,7 @@ class IPluginFactory(zope.interface.Interface):
 
     description = zope.interface.Attribute("Short plugin description")
 
-    def __call__(config, name):
+    def __call__(config, name):  # pylint: disable=signature-differs
         """Create new `IPlugin`.
 
         :param IConfig config: Configuration.
@@ -220,12 +219,6 @@ class IConfig(zope.interface.Interface):
 
     no_verify_ssl = zope.interface.Attribute(
         "Disable verification of the ACME server's certificate.")
-    tls_sni_01_port = zope.interface.Attribute(
-        "Port used during tls-sni-01 challenge. "
-        "This only affects the port Certbot listens on. "
-        "A conforming ACME server will still attempt to connect on port 443.")
-    tls_sni_01_address = zope.interface.Attribute(
-        "The address the server listens to during tls-sni-01 challenge.")
 
     http01_port = zope.interface.Attribute(
         "Port used in the http-01 challenge. "
@@ -235,6 +228,11 @@ class IConfig(zope.interface.Interface):
     http01_address = zope.interface.Attribute(
         "The address the server listens to during http-01 challenge.")
 
+    https_port = zope.interface.Attribute(
+        "Port used to serve HTTPS. "
+        "This affects which port Nginx will listen on after a LE certificate "
+        "is installed.")
+
     pref_challs = zope.interface.Attribute(
         "Sorted user specified preferred challenges"
         "type strings with the most preferred challenge listed first")
@@ -296,10 +294,10 @@ class IInstaller(IPlugin):
 
         :param str domain: domain for which to provide enhancement
         :param str enhancement: An enhancement as defined in
-            :const:`~certbot.constants.ENHANCEMENTS`
+            :const:`~certbot.plugins.enhancements.ENHANCEMENTS`
         :param options: Flexible options parameter for enhancement.
             Check documentation of
-            :const:`~certbot.constants.ENHANCEMENTS`
+            :const:`~certbot.plugins.enhancements.ENHANCEMENTS`
             for expected options for each enhancement.
 
         :raises .PluginError: If Enhancement is not supported, or if
@@ -311,7 +309,7 @@ class IInstaller(IPlugin):
         """Returns a `collections.Iterable` of supported enhancements.
 
         :returns: supported enhancements which should be a subset of
-            :const:`~certbot.constants.ENHANCEMENTS`
+            :const:`~certbot.plugins.enhancements.ENHANCEMENTS`
         :rtype: :class:`collections.Iterable` of :class:`str`
 
         """
@@ -356,13 +354,6 @@ class IInstaller(IPlugin):
 
         """
 
-    def view_config_changes():  # type: ignore
-        """Display all of the LE config changes.
-
-        :raises .PluginError: when config changes cannot be parsed
-
-        """
-
     def config_test():  # type: ignore
         """Make sure the configuration is valid.
 
@@ -380,7 +371,6 @@ class IInstaller(IPlugin):
 
 class IDisplay(zope.interface.Interface):
     """Generic display."""
-    # pylint: disable=too-many-arguments
     # see https://github.com/certbot/certbot/issues/3915
 
     def notification(message, pause, wrap=True, force_interactive=False):
@@ -542,6 +532,62 @@ class IReporter(zope.interface.Interface):
         """Prints messages to the user and clears the message queue."""
 
 
+@six.add_metaclass(abc.ABCMeta)
+class RenewableCert(object):
+    """Interface to a certificate lineage."""
+
+    @abc.abstractproperty
+    def cert_path(self):
+        """Path to the certificate file.
+
+        :rtype: str
+
+        """
+
+    @abc.abstractproperty
+    def key_path(self):
+        """Path to the private key file.
+
+        :rtype: str
+
+        """
+
+    @abc.abstractproperty
+    def chain_path(self):
+        """Path to the certificate chain file.
+
+        :rtype: str
+
+        """
+
+    @abc.abstractproperty
+    def fullchain_path(self):
+        """Path to the full chain file.
+
+        The full chain is the certificate file plus the chain file.
+
+        :rtype: str
+
+        """
+
+    @abc.abstractproperty
+    def lineagename(self):
+        """Name given to the certificate lineage.
+
+        :rtype: str
+
+        """
+
+    @abc.abstractmethod
+    def names(self):
+        """What are the subject names of this certificate?
+
+        :returns: the subject names
+        :rtype: `list` of `str`
+        :raises .CertStorageError: if could not find cert file.
+
+        """
+
 # Updater interfaces
 #
 # When "certbot renew" is run, Certbot will iterate over each lineage and check
@@ -580,7 +626,7 @@ class GenericUpdater(object):
         This method is called once for each lineage.
 
         :param lineage: Certificate lineage object
-        :type lineage: storage.RenewableCert
+        :type lineage: RenewableCert
 
         """
 
@@ -609,6 +655,6 @@ class RenewDeployer(object):
         This method is called once for each lineage renewed
 
         :param lineage: Certificate lineage object
-        :type lineage: storage.RenewableCert
+        :type lineage: RenewableCert
 
         """
