@@ -19,11 +19,11 @@ from six.moves import reload_module  # pylint: disable=import-error
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import serialization
 
-from certbot import configuration
-from certbot import constants
+from certbot._internal import configuration
+from certbot._internal import constants
 from certbot import interfaces
-from certbot import lock
-from certbot import storage
+from certbot._internal import lock
+from certbot._internal import storage
 from certbot import util
 from certbot.compat import os
 from certbot.compat import filesystem
